{% extends "base.html" %}

{% load markup %}

{% block extra_head %}
<script type="text/javascript">
{% include "vz_wiki/slug.js" %}
</script>
{% endblock %}

{% block content_title %}Create Page{% endblock %}

{% block content %}
<h3>Create page</h3>
<form method="POST" action="{% url create_page %}">
{{ form.as_p }}
<p><input type="submit" value="Create"></p>
{% endblock %}
