{% extends "base.html" %}

{% block content_title %}
Page Not Found
{% endblock %}

{% block content %}
<h3>Whoops...</h3>
<p>The page you were looking for at <em>{{request_path }}</em> was 
not found.</p>
{% endblock %}
